#! /usr/bin/env python

#reading the book, sentence by sentence, in the chat (needs a message to trigger the bot)
#it can be launched this way : $ python readerbot.py 10.1.1.1 '#frankenstein' readerbot
 
import irc.bot
from time import sleep
import time
import re

separator = ' [...]' 

"""
Functions
"""

def get_chunks(line):
    """
    Breaks lines up into chunks of a maximum of 512 characters long.
    However, we need to subtract the length of tweet_separator so we 
    can include it in tweets that contain partial sentences.
    """
    chunk_length = 450 - len(separator)
    line_length = len(line)
    # print line_length

    # If the line fits in one tweet, return it here.
    if line_length < 450:
        return [line]

    else:
        # In the script's main logic, we loop through this list and tweet
        # each entry.
        chunks = []

        # Break up the current line into tweets, ensuring that each tweet
        # breaks on a space, not within a word.
        line_remainder = line
        while len(line_remainder) > chunk_length:
            # Get the first chunk_length characters in the line.
            raw_slice = line[:chunk_length]
            # Find the position of the last space in the chunk.
            last_space = raw_slice.rfind(' ')
            # # Remove whatever in the line comes after the last space in
            # # the chunk.
            trimmed_slice = line[:last_space]
            # # Add the remaining chunk, plus tweet_separator, to the list of tweets.
            sentence = trimmed_slice.strip() + separator
            chunks.append(sentence)
            # # Get the string that follows the last space and reinitialize
            # # line with it.
            line_remainder = line[last_space:]
            line = line_remainder
       
        # When line_remainder is less than chunk_length, add it to 
        # the list of tweets.
        chunks.append(line_remainder.strip())

        return chunks
 
class Bot (irc.bot.SingleServerIRCBot):
    def __init__(self, server, channel, nickname, port=6667):
        irc.bot.SingleServerIRCBot.__init__(self, [(server, port)], nickname, nickname)
        self.channel = channel
 
    def on_nicknameinuse(self, c, e):
        c.nick(c.get_nickname() + "_")
 
    def on_welcome(self, c, e):
        c.join(self.channel)
 
    def on_pubmsg(self, c, e):
        msg = e.arguments[0]
        filename=open('frankenstein_gutenberg.txt','r')
        f=filename.read()
        filename.close()
#        with open('frankenstein_gutenberg.txt','r') as file:
#            print file.read()
        f = f.replace('\n', ' ')
        sentences = re.split(r'(?<!\w\.\w.)(?<![A-Z][a-z]\.)(?<=\.|\?)\s', f)
        for stuff in sentences:
            stuff = get_chunks(stuff)      
            for line_clean in stuff:
                print line_clean
                c.privmsg(self.channel, line_clean.strip())
                time.sleep(2)
 
#############################################
# Standard code to start the bot
#############################################
 
def main():
    import sys
    if not len(sys.argv) >= 3 :
        print "Usage: testbot server[:port] channel nickname"
        sys.exit(1)
 
    s = sys.argv[1].split(":", 1)
    server = s[0]
    if len(s) == 2:
        try:
            port = int(s[1])
        except ValueError:
            print "Error: Erroneous port."
            sys.exit(1)
    else:
        port = 6667
 
    channel = sys.argv[2]
 
    nickname = sys.argv[3]
    bot = Bot(server, channel, nickname, port)
    bot.start()
 
if __name__ == "__main__":
    main()
